mcconnell 02/02/01 16:52:27
Modified: apps/enterprise/pss/dist README.TXT
apps/enterprise/pss/src/etc README.TXT
apps/enterprise/pss/src/java/org/apache/pss Initializer.java
Log:
no message
Revision Changes Path
1.2 +2 -2
jakarta-avalon-cornerstone/apps/enterprise/pss/dist/README.TXT
Index: README.TXT
===================================================================
RCS file:
/home/cvs/jakarta-avalon-cornerstone/apps/enterprise/pss/dist/README.TXT,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- README.TXT 2 Feb 2002 00:33:00 -0000 1.1
+++ README.TXT 2 Feb 2002 00:52:27 -0000 1.2
@@ -41,8 +41,8 @@
contains the following files:
LICENSE.HTML, license and due credits
- OSM-PSDL-1.0, the PSDL compiler
- OSM-PSS-1.0, the PSS runtime
+ psdl-1.0.jar, the PSDL compiler
+ pss-1.0.jar, the PSS runtime
Changes introduced in the PSS 2.0 implementation (FEB 2002)
1.4 +10 -10
jakarta-avalon-cornerstone/apps/enterprise/pss/src/etc/README.TXT
Index: README.TXT
===================================================================
RCS file:
/home/cvs/jakarta-avalon-cornerstone/apps/enterprise/pss/src/etc/README.TXT,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- README.TXT 1 Feb 2002 23:08:45 -0000 1.3
+++ README.TXT 2 Feb 2002 00:52:27 -0000 1.4
@@ -41,8 +41,8 @@
contains the following files:
LICENSE.HTML, license and due credits
- OSM-PSDL-1.0, the PSDL compiler
- OSM-PSS-1.0, the PSS runtime
+ psdl-1.0.jar, the PSDL compiler
+ pss-1.0.jar, the PSS runtime
Changes introduced in the PSS 2.0 implementation (FEB 2002)
@@ -55,25 +55,25 @@
2. Upgrading of the implementation to the final adopted and available
specification (FTF results as detailed under the ptc/01-12-01.pdf
report and summarised under the revised specification ptd/01-12-02.pdf.
- 2. The source base for this PSS implementation is a result of the
+ 3. The source base for this PSS implementation is a result of the
decompilation of the OpenORB PSS binaries (resulting in elimination
of redundant code and generation of consistent code layout and
structure), reformatting of generated sources to be compliant with
the established project coding conventions, and enhancement to the
code base concerning generation of javadoc comments in generated code.
- 3. Documentation of license dependencies, due credits and declaimers.
- 4. Substantial enhancements to the javadoc generation capability,
+ 4. Documentation of license dependencies, due credits and declaimers.
+ 5. Substantial enhancements to the javadoc generation capability,
creation of documentation for all packages, documentation of all
classes, detailed documentation included in a new edition of the
CosPersistentState.idl IDL source.
- 5. Separation of compiler from PSS runtime distributions.
- 6. Elimination of bugs in the file connector that result in
+ 6. Separation of compiler from PSS runtime distributions.
+ 7. Elimination of bugs in the file connector that result in
non-availability of persistent data following a server restart.
- 7. Extensive introduction of exception handling across all connectors
+ 8. Extensive introduction of exception handling across all connectors
and the propagation of errors through cascading exceptions.
- 8. Introduction of Apache LogKit as the logging mechanism under the
+ 9. Introduction of Apache LogKit as the logging mechanism under the
Avalon abstract logging framework.
- 9. Introduction of defaults configuration using Avalon Configurable
+ 10. Introduction of defaults configuration using Avalon Configurable
interfaces and related implementations.
Version and Status
1.2 +3 -3
jakarta-avalon-cornerstone/apps/enterprise/pss/src/java/org/apache/pss/Initializer.java
Index: Initializer.java
===================================================================
RCS file:
/home/cvs/jakarta-avalon-cornerstone/apps/enterprise/pss/src/java/org/apache/pss/Initializer.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- Initializer.java 1 Feb 2002 22:35:11 -0000 1.1
+++ Initializer.java 2 Feb 2002 00:52:27 -0000 1.2
@@ -53,14 +53,14 @@
* PSS initializer that handles the establishment of inital references to a
* file, database and memory connector.
* Connectors are accessible to users through the resolve_inital_references
* operation using the "PSS:OSM:xxx" where "xxx" many be one of "file",
* "database" or "memory". Clients should narrow the returned instance to
* Connector using ConnectorHelper.narrow.
* <pre>
* org.omg.CosPersistentState.Connector connector = null;
* try
* {
- * org.omg.CORBA.Object object =
orb.resolve_initial_references("PSS:OSM:database");
+ * org.omg.CORBA.Object object =
orb.resolve_initial_references("PSS:APACHE:file");
* connector = org.omg.CosPersistentState.ConnectorHelper.narrow(
object );
* }
* catch( InvalidName invalidName )
@@ -116,7 +116,7 @@
try
{
defaults = getConfiguration( this.getClass(),
"org/apache/pss/config.xml" );
- vendor = defaults.getAttribute("vendor","OSM") + ":" ;
+ vendor = defaults.getAttribute("vendor","APACHE") + ":" ;
}
catch ( Throwable e )
{
@@ -53,14 +53,14 @@
* file, database and memory connector.
* Connectors are accessible to users through the resolve_inital_references
- * operation using the "PSS:OSM:xxx" where "xxx" many be one of "file",
+ * operation using the "PSS:APACHE:xxx" where "xxx" many be one of "file",
* "database" or "memory". Clients should narrow the returned instance to
* Connector using ConnectorHelper.narrow.
--
To unsubscribe, e-mail: <mailto:[EMAIL PROTECTED]>
For additional commands, e-mail: <mailto:[EMAIL PROTECTED]>